@@ -101,12 +101,17 @@ SUBWORD_TOKENIZER_TYPES = [
     "character",
 ]
 
+HALF_ASCII_TRANSLATE_TABLE = str.maketrans({chr(0xFF01 + _): chr(0x21 + _) for _ in range(94)})
+
 WORD_FORM_TYPES = {
     "surface": lambda m: m.surface(),
     "dictionary": lambda m: m.dictionary_form(),
     "normalized": lambda m: m.normalized_form(),
     "dictionary_and_surface": lambda m: m.surface() if m.part_of_speech()[0] in CONJUGATIVE_POS else m.dictionary_form(),
     "normalized_and_surface": lambda m: m.surface() if m.part_of_speech()[0] in CONJUGATIVE_POS else m.normalized_form(),
+    "surface_half_ascii": lambda m: m.surface().translate(HALF_ASCII_TRANSLATE_TABLE),
+    "dictionary_half_ascii": lambda m: m.dictionary_form().translate(HALF_ASCII_TRANSLATE_TABLE),
+    "dictionary_and_surface_half_ascii": lambda m: m.surface().translate(HALF_ASCII_TRANSLATE_TABLE) if m.part_of_speech()[0] in CONJUGATIVE_POS else m.dictionary_form().translate(HALF_ASCII_TRANSLATE_TABLE),
 }
 
 CONJUGATIVE_POS = {'動詞', '形容詞', '形容動詞', '助動詞'}
@@ -146,7 +151,7 @@ class BertSudachipyTokenizer(PreTrainedTokenizer):
             do_word_tokenize=True,
             do_subword_tokenize=True,
             word_tokenizer_type="sudachipy",
-            subword_tokenizer_type="pos_substitution",
+            subword_tokenizer_type="wordpiece",
             unk_token="[UNK]",
             sep_token="[SEP]",
             pad_token="[PAD]",
@@ -157,18 +162,18 @@ class BertSudachipyTokenizer(PreTrainedTokenizer):
             **kwargs
     ):
         super().__init__(
-            do_lower_case=False,
-            do_word_tokenize=True,
-            do_subword_tokenize=True,
-            word_tokenizer_type="sudachipy",
-            subword_tokenizer_type="pos_substitution",
+            do_lower_case=do_lower_case,
+            do_word_tokenize=do_word_tokenize,
+            do_subword_tokenize=do_subword_tokenize,
+            word_tokenizer_type=word_tokenizer_type,
+            subword_tokenizer_type=subword_tokenizer_type,
             unk_token=unk_token,
             sep_token=sep_token,
             pad_token=pad_token,
             cls_token=cls_token,
             mask_token=mask_token,
-            word_form_type="surface",
-            sudachipy_kwargs=None,
+            word_form_type=word_form_type,
+            sudachipy_kwargs=sudachipy_kwargs,
             **kwargs,
         )
 
